export type Fetch = (input: RequestInfo | URL, init?: RequestInit | undefined) => Promise<Response>;
type CreateNetlifyExtensionUIFetchOptions = {
    fetch?: Fetch | undefined;
    configurationId?: string | null | undefined;
    dataLayerId?: string | null | undefined;
    extension: {
        id: string;
        slug: string;
    };
    netlifyToken?: string | null | undefined;
    netlifyTokenHeader?: string | null | undefined;
    providerToken?: string | null | undefined;
    providerTokens?: {
        externalId: string;
        token: string;
        connectionId: string;
    }[] | undefined;
    siteId?: string | null | undefined;
    teamId?: string | null | undefined;
    user: {
        id: string | null;
    };
};
export declare const createNetlifyExtensionUIFetch: ({ fetch, ...options }: CreateNetlifyExtensionUIFetchOptions) => Fetch;
/**
 * `useNetlifyExtensionUIFetch` returns a `fetch`-compatible function that automatically attaches
 * authentication data to requests. Use it to perform requests to [endpoints](/sdk/endpoints/overview/).
 *
 * @returns A fetch function.
 * @example
 * ```tsx
 * import { useNetlifyExtensionUIFetch } from "@netlify/sdk/react";
 * import { useEffect, useState } from "react";
 *
 * const MyComponent = () => {
 *   const fetch = useNetlifyExtensionUIFetch();
 *   const [data, setData] = useState(null);
 *
 *   useEffect(() => {
 *     (async () => {
 *       const res = await fetch("/.netlify/functions/my-endpoint");
 *       if (res.ok) {
 *         setData(await res.json());
 *       }
 *     })();
 *   }, [fetch, setData]);
 *
 *   if (data === null) {
 *     return <div>No data found.</div>;
 *   }
 * };
 * ```
 */
export declare const useNetlifyExtensionUIFetch: () => Fetch;
export {};
//# sourceMappingURL=use_netlify_extension_ui_fetch.d.ts.map